// growth_level_forecast.mod
// standard growth model: variables are the level of consumption, the level of capital, and the log of productivity
// Dynare generates a law of motion that is linear in these variables (order = 1)  or quadratic (order = 2).

var c, k, lnz;
varexo e;
parameters beta, rho, alpha, phi, delta, sig;

alpha = 0.36; rho   = 0.95; beta  = 0.99;
phi   = 3.00; delta = 0.10; sig = 0.01;

zz=[alpha;rho;beta;phi;delta;sig];
model;
c^(-phi)=beta*c(+1)^(-phi)*(exp(lnz(+1))*alpha*k^(alpha-1)+1-delta);
c+k=exp(lnz)*k(-1)^alpha+(1-delta)*k(-1);
lnz = rho*lnz(-1)+e;
end;

initval;
c = exp(-1.02); k = exp(-1.61); lnz = 0;
end;

shocks;
var e;  stderr sig;
end;

steady(solve_algo=0);
check;

stoch_simul(order=1,IRF=100);

forecast(periods=16,conf_sig=0.95);   % these are unconditional forecast
                                      % the forecasts are stored into oo_.Forecast_Mean_variablename


%%%%%%%%%%%%%%%%%%%%%%%%%  THIS PART DOES NOT WORK YET WITH CALIBRATED PARAMETERS, ONLY WITH ESTIMATED ONES %%%
conditional_forecast_paths;
var k;
periods 1:5;
values 2;
end;

%estimated_params;
%alpha,0.36,0.3,0.4,BETA_PDF,0.36,0.1; 
%rho,BETA_PDF,0.95,0.1; 
%beta,BETA_PDF,0.99,0.01;
%phi,GAMMA_PDF,3.00,1; 
%delta,BETA_PDF,0.10,0.1; 
%sig,GAMMA_PDF,0.01,0.001;
%end;

%conditional_forecast(parameter_set=prior_mean,controlled_varexo=(e), replic=100, conf_sig=0.95);
%conditional_forecast(parameter_set=calibration, controlled_varexo=(e), replic=100, conf_sig=0.95);

%plot_conditional_forecasts(periods=10) e c;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

// exercise 1: use a 68 % confidence interval for forecasts
// exercise 2: do forecasts for 40 periods
 