// growth_log_calib.mod
// standard growth model calibrated to the steady states
// variables are the log of consumption, the log of capital, and the log of productivity
// Dynare generates a law of motion that is linear in these variables (order = 1) or quadratic (order = 2).

var lnc, lnk, lnz;
varexo e;
parameters beta, rho, alpha, phi, delta, sig;

% initial conditions for the parameters to be calibrated
alp0  = 0.36; 
bet0  = 0.99; 
phi0  = 2.0; %1.0
delta0 = 0.025;

%thet0=[phi0;alp0;bet0;delta0];    
thet0=[phi0;alp0;bet0];    
 
%% Call the function 'growth_log_calib_ss' to solve for thet that matches ss
sol=fcsolve('growth_log_calib_ss',thet0,[]);  
 
phi=sol(1); 
alpha=sol(2); 
beta=sol(3);
delta=0.025; 

// parameters not entering the steady states
rho = 0.95;
sig = 0.01;

model;
exp(-phi*lnc)=beta*(exp(-phi*lnc(+1)))*(exp(lnz(+1))*alpha*exp((alpha-1)*lnk)+1-delta);
exp(lnc)+exp(lnk)=exp(lnz+alpha*lnk(-1))+(1-delta)*exp(lnk(-1));
lnz = rho*lnz(-1)+e;
end;

shocks;
var e;  stderr sig;
end;

stoch_simul(order=1,nocorr,nomoments,IRF=10);

// exercise 1: change initial values for the parameters
// exercise 2: repeat exercise 1 for order = 1
// exercise 3: does the calibrated value of delta matters? try delta=0.03.
 